@@ -21,6 +21,7 @@
 #include "ui_settings_misc.h"
 #include "ui_settings_units.h"
 #include "ui_settings_web.h"
+#include "ui_settings_calc.h"
 #include "elementdataviewer.h"
 #include "detailinfodlg.h"
 #include "periodictableview.h"
@@ -46,6 +47,8 @@
 
 #include <config-kalzium.h>
 
+#include "calculator/calculator.h"
+
 #ifdef HAVE_FACILE
 #include "eqchemview.h"
 #endif
@@ -58,14 +61,10 @@
 #endif
 
 #include <QDockWidget>
-#include <QLayout>
 #include <QToolBox>
 #include <QScrollArea>
 #include <QKeyEvent>
-#include <QTimer>
-#include <QSvgGenerator>
 #include <QRegExp>
-#include <QDebug>
 
 #include <kmessagebox.h>
 #include <kconfigdialog.h>
@@ -207,7 +206,7 @@ void Kalzium::setupActions()
     look_action_gradients->setToolBarMode( KSelectAction::MenuMode );
     look_action_gradients->setToolButtonPopupMode( QToolButton::InstantPopup );
     connect( look_action_gradients, SIGNAL( triggered( int ) ), this, SLOT( slotSwitchtoLookGradient( int ) ) );
-    
+
     // the action for swiching tables
     QStringList tablelist;
     QStringList table_schemes = KalziumTableTypeFactory::instance()->tables();
@@ -229,6 +228,7 @@ void Kalzium::setupActions()
     m_EQSolverAction->setText( i18n( "&Equation Solver..." ) );
     m_EQSolverAction->setIcon(  KIcon( "eqchem" ) );
     m_EQSolverAction->setWhatsThis( i18nc( "WhatsThis Help", "This tool allows you to solve chemical equations." ) );
+
 #ifdef HAVE_FACILE
     connect( m_EQSolverAction, SIGNAL( triggered() ), this, SLOT( slotShowEQSolver() ) );
     m_EQSolverAction->setEnabled( true );
@@ -242,6 +242,13 @@ void Kalzium::setupActions()
     m_pPlotAction->setIcon( KIcon( "plot" ) );
     connect( m_pPlotAction, SIGNAL( triggered() ), this, SLOT( slotPlotData() ) );
 
+    // calculator actions
+    m_pcalculator = actionCollection()->addAction( "tools_calculate" );
+    m_pcalculator->setText( i18n( "Perform &Calculations..." ) );
+    m_pcalculator->setIcon( KIcon( "calculate" ) );
+    m_pcalculator->setWhatsThis( i18nc( "WhatsThis Help", "This is the calculator, it performs basic chemical calculations." ) );
+    connect( m_pcalculator, SIGNAL( triggered() ), this, SLOT( showCalculator() ) );    
+
     m_pIsotopeTableAction= actionCollection()->addAction( "tools_isotopetable" );
     m_pIsotopeTableAction->setText( i18n( "&Isotope Table..." ) );
     m_pIsotopeTableAction->setIcon(  KIcon( "isotopemap" ) );
@@ -379,6 +386,7 @@ void Kalzium::setupSidebars()
 
     m_calcWidget = new MolcalcWidget( m_toolbox );
     m_calcWidget->setObjectName( "molcalcwidget" );
+    m_calcWidget->hideExtra();
     m_toolbox->addItem( m_calcWidget, KIcon( "calculate" ), i18n( "Calculate" ) );
 
     connect( m_toolbox, SIGNAL( currentChanged( int ) ), 
@@ -469,6 +477,12 @@ void Kalzium::slotPlotData()
 	edw->show();
 }
 
+void Kalzium::showCalculator()
+{
+	calculator *Cal = new calculator ( this ); 
+	Cal -> show();	
+}
+
 void Kalzium::slotShowLegend( bool checked, bool changeconfig)
 {
 	if ( !checked )
@@ -631,12 +645,17 @@ void Kalzium::showSettingsDialog()
 	w_misc->setObjectName( "miscpage" );
 	ui_misc.setupUi( w_misc );
 	dialog->addPage( w_misc, i18n( "Miscellaneous" ), "preferences-other" );
-    //wiki page
+    // web page
     Ui_setupWeb ui_web;
     QWidget *w_web = new QWidget( 0 );
     //w_web->setobjectName( "Web_lookup" );
     ui_web.setupUi( w_web );
-    dialog->addPage( w_web, i18n(" Web look up" ), "preferences-system-network");	
+    dialog->addPage( w_web, i18n(" Web look up" ), "preferences-system-network");
+    
+    Ui_setupCalc ui_calc;
+    QWidget *w_calc = new QWidget( 0 );
+    ui_calc.setupUi( w_calc );
+    dialog->addPage( w_calc, i18n("Calculator"), "preferences-calculator");
 	
 	// showing the dialog
 	dialog->show();
