@@ -30,7 +30,7 @@ class ObjectType;
 class BaseConstructMode;
 
 class QString;
-class QCString;
+class QByteArray;
 
 /**
  * This class represents a way to construct a set of objects from a
@@ -48,20 +48,20 @@ public:
 
   virtual const QString descriptiveName() const = 0;
   virtual const QString description() const = 0;
-  virtual const QCString iconFileName( const bool canBeNull = false ) const = 0;
+  virtual const QByteArray iconFileName( const bool canBeNull = false ) const = 0;
 
   /**
    * the following function is called in case of duplication of arguments
    * and returns true if this is acceptable; this will return false for
    * typical objects
    */
-  virtual const bool isAlreadySelectedOK( const std::vector<ObjectCalcer*>& os, 
-                              const int& ) const = 0;
+  virtual bool isAlreadySelectedOK( const std::vector<ObjectCalcer*>& os, 
+                              const uint& ) const = 0;
   /**
    * can this constructor do something useful with \p os ?  return
    * ArgsParser::Complete, Valid or NotGood
    */
-  virtual const int wantArgs( const std::vector<ObjectCalcer*>& os,
+  virtual int wantArgs( const std::vector<ObjectCalcer*>& os,
                               const KigDocument& d,
                               const KigWidget& v
     ) const = 0;
@@ -147,11 +147,11 @@ public:
 
   const QString descriptiveName() const;
   const QString description() const;
-  const QCString iconFileName( const bool canBeNull = false ) const;
+  const QByteArray iconFileName( const bool canBeNull = false ) const;
 
-  const bool isAlreadySelectedOK( const std::vector<ObjectCalcer*>& os, 
-                                  const int& ) const;
-  virtual const int wantArgs(
+  bool isAlreadySelectedOK( const std::vector<ObjectCalcer*>& os, 
+                                  const uint& ) const;
+  virtual int wantArgs(
     const std::vector<ObjectCalcer*>& os, const KigDocument& d,
     const KigWidget& v
     ) const;
@@ -299,11 +299,11 @@ public:
 
   const QString descriptiveName() const;
   const QString description() const;
-  const QCString iconFileName( const bool canBeNull = false ) const;
+  const QByteArray iconFileName( const bool canBeNull = false ) const;
 
-  const bool isAlreadySelectedOK( const std::vector<ObjectCalcer*>& os, 
-                                  const int& ) const;
-  const int wantArgs( const std::vector<ObjectCalcer*>& os,
+  bool isAlreadySelectedOK( const std::vector<ObjectCalcer*>& os, 
+                                  const uint& ) const;
+  int wantArgs( const std::vector<ObjectCalcer*>& os,
                       const KigDocument& d,
                       const KigWidget& v
     ) const;
@@ -340,26 +340,26 @@ class MacroConstructor
   QString mname;
   QString mdesc;
   bool mbuiltin;
-  QCString miconfile;
+  QByteArray miconfile;
   ArgsParser mparser;
 public:
   MacroConstructor( const std::vector<ObjectCalcer*>& input, const std::vector<ObjectCalcer*>& output,
                     const QString& name, const QString& description,
-                    const QCString& iconfile = 0 );
+                    const QByteArray& iconfile = 0 );
   MacroConstructor( const ObjectHierarchy& hier, const QString& name,
                     const QString& desc,
-                    const QCString& iconfile = 0 );
+                    const QByteArray& iconfile = 0 );
   ~MacroConstructor();
 
   const ObjectHierarchy& hierarchy() const;
 
   const QString descriptiveName() const;
   const QString description() const;
-  const QCString iconFileName( const bool canBeNull = false ) const;
+  const QByteArray iconFileName( const bool canBeNull = false ) const;
 
-  const bool isAlreadySelectedOK( const std::vector<ObjectCalcer*>& os, 
-                                  const int& ) const;
-  const int wantArgs( const std::vector<ObjectCalcer*>& os, const KigDocument& d,
+  bool isAlreadySelectedOK( const std::vector<ObjectCalcer*>& os, 
+                                  const uint& ) const;
+  int wantArgs( const std::vector<ObjectCalcer*>& os, const KigDocument& d,
                       const KigWidget& v ) const;
 
   void handleArgs( const std::vector<ObjectCalcer*>& os, KigPart& d,
@@ -390,7 +390,7 @@ public:
 
   void setName( const QString& name );
   void setDescription( const QString& desc );
-  void setIcon( QCString& icon );
+  void setIcon( QByteArray& icon );
 };
 
 #endif
