@@ -26,8 +26,8 @@
 
 #include "dms.h"
 #include "widgets/dmsbox.h"
-#include "skypoint.h"
-#include "finddialog.h"
+#include "skyobjects/skypoint.h"
+#include "dialogs/finddialog.h"
 #include "kstars.h"
 
 modCalcAngDist::modCalcAngDist(QWidget *parentSplit)
@@ -91,9 +91,9 @@ void modCalcAngDist::slotValidatePositions(){
 }
 
 void modCalcAngDist::slotObjectButton() {
-    FindDialog fd( (KStars*)topLevelWidget()->parent() );
-    if ( fd.exec() == QDialog::Accepted ) {
-        SkyObject *o = fd.selectedObject();
+    QPointer<FindDialog> fd = new FindDialog( (KStars*)topLevelWidget()->parent() );
+    if ( fd->exec() == QDialog::Accepted ) {
+        SkyObject *o = fd->selectedObject();
         if ( sender()->objectName() == QString("FirstObjectButton") ) {
             FirstRA->showInHours( o->ra() );
             FirstDec->showInDegrees( o->dec() );
@@ -106,6 +106,7 @@ void modCalcAngDist::slotObjectButton() {
 
         slotValidatePositions();
     }
+    delete fd;
 }
 
 void modCalcAngDist::slotResetTitle() {
@@ -141,7 +142,7 @@ void modCalcAngDist::slotRunBatch() {
         if ( !f.open( QIODevice::ReadOnly) ) {
             QString message = i18n( "Could not open file %1.", f.fileName() );
             KMessageBox::sorry( 0, message, i18n( "Could Not Open File" ) );
-            inputFileName = QString();
+            inputFileName.clear();
             return;
         }
 
@@ -153,7 +154,7 @@ void modCalcAngDist::slotRunBatch() {
     } else  {
         QString message = i18n( "Invalid file: %1", inputFileName );
         KMessageBox::sorry( 0, message, i18n( "Invalid file" ) );
-        inputFileName = QString();
+        inputFileName.clear();
         InputLineEditBatch->setText( inputFileName );
         return;
     }
@@ -172,7 +173,7 @@ void modCalcAngDist::processLines( QTextStream &istream ) {
     QTextStream ostream(&fOut);
 
     QString line;
-    QString space = " ";
+    QChar space = ' ';
     int i = 0;
     SkyPoint sp0, sp1;
     dms ra0B, dec0B, ra1B, dec1B, dist;
@@ -183,7 +184,7 @@ void modCalcAngDist::processLines( QTextStream &istream ) {
 
         //Go through the line, looking for parameters
 
-        QStringList fields = line.split( " " );
+        QStringList fields = line.split( ' ' );
 
         i = 0;
 
