@@ -22,6 +22,7 @@
 #define _CANVAS_H_
 
 #include <QGraphicsView>
+#include <QSvgGenerator>
 
 #include "sprite.h"
 
@@ -35,6 +36,9 @@ class Canvas : public QGraphicsView
 		~Canvas();
 
 		double turtleAngle() { return turtle->angle(); }
+		QImage getPicture();
+		void saveAsSvg(const QString&, const QString&);
+// 		void scene() { return _scene; }
 
 	public slots:
 		void slotClear();
@@ -72,7 +76,7 @@ class Canvas : public QGraphicsView
 		void wheelEvent(QWheelEvent *event);
 		void scaleView(double scaleFactor);
 
-		QGraphicsScene            *scene;
+		QGraphicsScene            *_scene;
 		QPen                      *pen;
 		Sprite                    *turtle;
 		QList<QGraphicsLineItem*>  lines;
