@@ -5,7 +5,7 @@
 // find a copy of this license in LICENSE.txt in the top directory of
 // the source code.
 //
-// Copyright 2008-2009    Torsten Rahn <tackat@kde.org>"
+// Copyright 2008-2009    Torsten Rahn <tackat@kde.org>
 //
 
 //
@@ -27,7 +27,8 @@ namespace Marble
 
 class AbstractTilePrivate;
 
-class AbstractTile : public QObject {
+class AbstractTile : public QObject
+{
     Q_OBJECT
 
  public:
