@@ -5,13 +5,12 @@
 // find a copy of this license in LICENSE.txt in the top directory of
 // the source code.
 //
-// Copyright 2006-2007 Torsten Rahn <tackat@kde.org>"
-// Copyright 2007      Inge Wallin  <ingwa@kde.org>"
+// Copyright 2006-2007 Torsten Rahn <tackat@kde.org>
+// Copyright 2007      Inge Wallin  <ingwa@kde.org>
 //
 
 #include "DeferredFlag.h"
 
-#include <QtCore/QDebug>
 #include <QtGui/QColor>
 #include <QtGui/QPainter>
 #include <QtGui/QPainterPath>
@@ -19,6 +18,7 @@
 #include <QtSvg/QSvgRenderer>
 
 #include "MarbleDirs.h"
+#include "MarbleDebug.h"
 
 using namespace Marble;
 
