@@ -14,7 +14,9 @@
 #include <cmath>
 
 #include <QtCore/QCoreApplication>
-#include <QtCore/QDebug>
+#include <QtCore/QHash>
+#include <QtCore/QSettings>
+#include <QtCore/QTime>
 #include <QtCore/QTimer>
 #include <QtCore/QAbstractItemModel>
 #include <QtGui/QItemSelectionModel>
@@ -22,6 +24,8 @@
 #include <QtGui/QPaintEvent>
 #include <QtGui/QRegion>
 #include <QtGui/QStyleOptionGraphicsItem>
+#include <QtGui/QMainWindow>
+#include <QtGui/QAction>
 #include <QtNetwork/QNetworkProxy>
 
 #ifdef MARBLE_DBUS
@@ -30,6 +34,7 @@
 
 #include "AbstractProjection.h"
 #include "MarbleDirs.h"
+#include "MarbleDebug.h"
 #include "MarbleMap.h"
 #include "MarbleModel.h"
 #include "Quaternion.h"
@@ -37,13 +42,12 @@
 #include "GeoPainter.h"
 #include "FileViewModel.h"
 #include "GeoDataCoordinates.h"
-#include "GpxFileViewItem.h"
 #include "MarblePhysics.h"
 #include "MarblePlacemarkModel.h"
 #include "MarbleWidgetInputHandler.h"
 #include "TileCreatorDialog.h"
-#include "gps/GpxFile.h"
 #include "gps/GpsLayer.h"
+#include "RenderPlugin.h"
 #include "SunLocator.h"
 #include "MergedLayerDecorator.h"
 #include "ViewportParams.h"
@@ -59,6 +63,8 @@ namespace Marble
 # endif
 #endif
 
+const int REPAINT_SCHEDULING_INTERVAL = 1000;
+
 
 class MarbleWidgetPrivate
 {
@@ -68,14 +74,16 @@ class MarbleWidgetPrivate
           m_map( map ),
           m_model( map->model() ),
           m_viewContext( Marble::Still ),
-          m_stillQuality( Marble::High ), m_animationQuality( Marble::Low ),
+          m_stillQuality( Marble::HighQuality ),
+          m_animationQuality( Marble::LowQuality ),
           m_animationsEnabled( false ),
           m_inputhandler( 0 ),
           m_physics( new MarblePhysics( parent ) ),
           m_proxyHost(),
           m_proxyPort( 0 ),
           m_user(),
-          m_password()
+          m_password(),
+          m_repaintTimer()
     {
     }
 
@@ -106,10 +114,14 @@ class MarbleWidgetPrivate
 
     MarblePhysics    *m_physics;
 
+    //This stuff is NEVER used. Needs to be deleted
     QString          m_proxyHost;
     qint16           m_proxyPort;
     QString          m_user;
     QString          m_password;
+
+    // For scheduling repaints
+    QTimer           m_repaintTimer;
 };
 
 
@@ -134,7 +146,7 @@ MarbleWidget::MarbleWidget(MarbleMap *map, QWidget *parent)
 MarbleWidget::~MarbleWidget()
 {
     // Remove and delete an existing InputHandler
-    // initiazized in d->construct()
+    // initialized in d->construct()
     setInputHandler( 0 );
 
     delete d;
@@ -151,6 +163,9 @@ void MarbleWidgetPrivate::construct()
     m_widget->setMinimumSize( 200, 300 );
     m_widget->setFocusPolicy( Qt::WheelFocus );
     m_widget->setFocus( Qt::OtherFocusReason );
+#if QT_VERSION >= 0x40600
+    m_widget->setAttribute( Qt::WA_AcceptTouchEvents );
+#endif
 
     // Initialize the map and forward some signals.
     m_map->setSize( m_widget->width(), m_widget->height() );
@@ -166,6 +181,14 @@ void MarbleWidgetPrivate::construct()
     m_widget->connect( m_model,  SIGNAL( modelChanged() ),
 		       m_widget, SLOT( updateChangedMap() ) );
 
+    // Repaint scheduling
+    m_widget->connect( m_map,    SIGNAL( repaintNeeded( QRegion ) ),
+                       m_widget, SLOT( scheduleRepaint( QRegion ) ) );
+    m_repaintTimer.setSingleShot( true );
+    m_repaintTimer.setInterval( REPAINT_SCHEDULING_INTERVAL );
+    m_widget->connect( &m_repaintTimer, SIGNAL( timeout() ),
+                       m_widget, SLOT( update() ) );
+
     // When some fundamental things change in the map, we got to show
     // this in the view, i.e. here.
     m_widget->connect( m_map,    SIGNAL( zoomChanged( int ) ),
@@ -190,8 +213,8 @@ void MarbleWidgetPrivate::construct()
 
     m_logZoom  = 0;
 
-    m_widget->connect( m_model->sunLocator(), SIGNAL( reenableWidgetInput() ),
-                       m_widget, SLOT( enableInput() ) );
+    m_widget->connect( m_model->sunLocator(), SIGNAL( enableWidgetInput(bool) ),
+                       m_widget, SLOT( setInputEnabled( bool ) ) );
 
     m_widget->connect( m_model->sunLocator(), SIGNAL( updateStars() ),
                        m_widget, SLOT( update() ) );
@@ -204,6 +227,12 @@ void MarbleWidgetPrivate::construct()
 
     m_widget->setInputHandler( new MarbleWidgetDefaultInputHandler );
     m_widget->setMouseTracking( m_widget );
+
+    m_widget->connect( m_model, SIGNAL( pluginSettingsChanged() ),
+                       m_widget, SIGNAL( pluginSettingsChanged() ) );
+                       
+    m_widget->connect( m_model, SIGNAL( renderPluginInitialized( RenderPlugin * ) ),
+                       m_widget, SIGNAL( renderPluginInitialized( RenderPlugin * ) ) );
 }
 
 // ----------------------------------------------------------------
@@ -237,6 +266,10 @@ void MarbleWidget::setInputHandler(MarbleWidgetInputHandler *handler)
     }
 }
 
+MarbleWidgetInputHandler *MarbleWidget::inputHandler() const
+{
+  return d->m_inputhandler;
+}
 
 Quaternion MarbleWidget::planetAxis() const
 {
@@ -584,6 +617,29 @@ void MarbleWidget::centerOn( const GeoDataCoordinates &position, bool animated )
     repaint();
 }
 
+void MarbleWidget::centerOn( const GeoDataLatLonBox &box, bool animated )
+{
+    Q_UNUSED(animated);
+    //work out the needed zoom level
+    ViewportParams* viewparams = d->m_map->viewParams()->viewport();
+    int maxScreenSize = viewparams->height() > viewparams->width() ?
+                     viewparams->height() : viewparams->width();
+
+    qreal maxBoundingSize = box.height() > box.width() ? box.height() : box.width();
+
+    //prevent divide by zero
+    if( maxBoundingSize ) {
+        int zoomRadius = ( 0.25 * M_PI ) * ( maxScreenSize / maxBoundingSize );
+        setRadius( zoomRadius );
+    }
+
+    //move the map
+    d->m_map->centerOn( box.center().longitude( GeoDataCoordinates::Degree ),
+                        box.center().latitude( GeoDataCoordinates::Degree ) );
+
+    repaint();
+}
+
 void MarbleWidget::updateAnimation( qreal updateValue )
 {
     GeoDataCoordinates position = d->m_physics->suggestedPosition();
@@ -776,6 +832,8 @@ const QRegion MarbleWidget::mapRegion()
 
 void MarbleWidget::paintEvent(QPaintEvent *evt)
 {
+    // Stop repaint timer if it is already running
+    d->m_repaintTimer.stop();
     QTime t;
     t.start();
 
@@ -785,9 +843,23 @@ void MarbleWidget::paintEvent(QPaintEvent *evt)
         doClip = ( d->m_map->radius() > width() / 2
                    || d->m_map->radius() > height() / 2 );
 
+    QPaintDevice *paintDevice = this;
+    QImage image;
+    if (!isEnabled())
+    {
+        // If the globe covers fully the screen then we can use the faster
+        // RGB32 as there are no translucent areas involved.
+        QImage::Format imageFormat = ( map()->mapCoversViewport() )
+                                     ? QImage::Format_RGB32
+                                     : QImage::Format_ARGB32_Premultiplied;
+        // Paint to an intermediate image
+        image = QImage(rect().size(), imageFormat);
+        paintDevice = &image;
+    }
+
     // Create a painter that will do the painting.
-    GeoPainter painter( this, map()->viewParams()->viewport(),
-			map()->viewParams()->mapQuality(), doClip );
+    GeoPainter painter( paintDevice, map()->viewParams()->viewport(),
+                        map()->viewParams()->mapQuality(), doClip );
 
     QRect  dirtyRect = evt->rect();
 
@@ -797,9 +869,26 @@ void MarbleWidget::paintEvent(QPaintEvent *evt)
     customPaint( &painter );
     d->m_map->d->paintOverlay( painter, dirtyRect );
 
-    qreal fps = 1000.0 / (qreal)( t.elapsed() + 1 );
-    d->m_map->d->paintFps( painter, dirtyRect, fps );
-    emit d->m_map->framesPerSecond( fps );
+    if (!isEnabled())
+    {
+        // Draw a grayscale version of the intermediate image
+        QRgb* pixel = reinterpret_cast<QRgb*>(image.scanLine(0));
+        for (int i=0; i<image.width()*image.height(); ++i, ++pixel) {
+            int gray = qGray(*pixel);
+            *pixel = qRgb(gray,gray,gray);
+        }
+
+        GeoPainter widgetPainter( this, map()->viewParams()->viewport(),
+                            map()->viewParams()->mapQuality(), doClip );
+        widgetPainter.drawImage(rect(), image);
+    }
+
+    if (d->m_map->showFrameRate())
+    {
+        qreal fps = 1000.0 / (qreal)( t.elapsed() + 1 );
+        d->m_map->d->paintFps( painter, dirtyRect, fps );
+        emit d->m_map->framesPerSecond( fps );
+    }
 }
 
 void MarbleWidget::customPaint(GeoPainter *painter)
@@ -852,7 +941,7 @@ GeoSceneDocument *MarbleWidget::mapTheme() const
 
 void MarbleWidget::setPropertyValue( const QString& name, bool value )
 {
-    qDebug() << "In MarbleWidget the property " << name << "was set to " << value;
+    mDebug() << "In MarbleWidget the property " << name << "was set to " << value;
     d->m_map->setPropertyValue( name, value );
 
     // Update texture map during the repaint that follows:
@@ -1023,18 +1112,14 @@ void MarbleWidget::updateGps()
                                                          d->m_map->viewParams(),
                                                          temp );
     if ( draw ) {
-//        qDebug() << "Updating viewport for GPS";
+//        mDebug() << "Updating viewport for GPS";
         update( temp );
     }
 }
 
 void MarbleWidget::openGpxFile(QString &filename)
 {
-    GpxFile* gpxFile = new GpxFile( filename );
-    GpxFileViewItem* item = new GpxFileViewItem( gpxFile );
-
-    d->m_model->fileViewModel()->append( item );
-    d->m_model->gpsLayer()->addGpxFile( gpxFile );
+    d->m_map->openGpxFile(filename);
 }
 
 GpxFileModel *MarbleWidget::gpxFileModel()
@@ -1059,7 +1144,7 @@ void MarbleWidget::setPersistentTileCacheLimit( quint64 kiloBytes )
 
 void MarbleWidget::clearVolatileTileCache()
 {
-    qDebug() << "About to clear VolatileTileCache";
+    mDebug() << "About to clear VolatileTileCache";
     d->m_map->clearVolatileTileCache();
 }
 
@@ -1086,6 +1171,14 @@ void MarbleWidget::updateChangedMap()
     update();
 }
 
+void MarbleWidget::scheduleRepaint( QRegion dirtyRegion )
+{
+    Q_UNUSED(dirtyRegion);
+    if ( !d->m_repaintTimer.isActive() ) {
+        d->m_repaintTimer.start();
+    }
+}
+
 MapQuality MarbleWidget::mapQuality( ViewContext viewContext )
 {
     if ( viewContext == Still )
@@ -1163,7 +1256,7 @@ void MarbleWidget::setSelection(const QRect& region)
 {
     QPoint tl = region.topLeft();
     QPoint br = region.bottomRight();
-    qDebug() << "Selection region: (" << tl.x() << ", " <<  tl.y() << ") (" 
+    mDebug() << "Selection region: (" << tl.x() << ", " <<  tl.y() << ") (" 
              << br.x() << ", " << br.y() << ")" << endl;
 
     AbstractProjection *proj = d->m_map->viewParams()->currentProjection();
@@ -1175,7 +1268,7 @@ void MarbleWidget::setSelection(const QRect& region)
     coordinates << box.west(GeoDataPoint::Degree) << box.north(GeoDataPoint::Degree)
                 << box.east(GeoDataPoint::Degree) << box.south(GeoDataPoint::Degree);
 
-    qDebug() << "West: " << coordinates[0] << " North: " <<  coordinates[1]
+    mDebug() << "West: " << coordinates[0] << " North: " <<  coordinates[1]
              << " East: " << coordinates[2] << " South: " << coordinates[3] << endl;
 
     emit regionSelected(coordinates);
@@ -1201,10 +1294,10 @@ void MarbleWidget::updateSun()
     // Update the sun shading.
     //SunLocator  *sunLocator = d->m_model->sunLocator();
 
-    qDebug() << "MarbleWidget: Updating the sun shading map...";
+    mDebug() << "MarbleWidget: Updating the sun shading map...";
     d->m_model->update();
     setNeedsUpdate();
-    //qDebug() << "Finished updating the sun shading map";
+    //mDebug() << "Finished updating the sun shading map";
 }
 
 void MarbleWidget::centerSun()
@@ -1216,7 +1309,7 @@ void MarbleWidget::centerSun()
         qreal  lat = sunLocator->getLat();
         centerOn( lon, lat );
 
-        disableInput();
+        setInputEnabled( false );
     }
 }
 
@@ -1225,59 +1318,62 @@ SunLocator* MarbleWidget::sunLocator()
     return d->m_model->sunLocator();
 }
 
-void MarbleWidget::enableInput()
+void MarbleWidget::setInputEnabled( bool enabled )
 {
-    if ( !d->m_inputhandler ) {
-        setInputHandler( new MarbleWidgetDefaultInputHandler );
+    //if input is set as enabled
+    if ( enabled )
+    {
+        if ( !d->m_inputhandler ) {
+            setInputHandler( new MarbleWidgetDefaultInputHandler );
+        }
+        else {
+            installEventFilter( d->m_inputhandler );
+        }
     }
-    else {
-        installEventFilter( d->m_inputhandler );
-    }
-}
 
-void MarbleWidget::disableInput()
-{
-    qDebug() << "MarbleWidget::disableInput";
-    removeEventFilter( d->m_inputhandler );
-    setCursor( Qt::ArrowCursor );
+    else // input is disabled
+    {
+        mDebug() << "MarbleWidget::disableInput";
+        removeEventFilter( d->m_inputhandler );
+        setCursor( Qt::ArrowCursor );
+    }
 }
 
 void MarbleWidget::setProxy( const QString& proxyHost, const quint16 proxyPort, const QString& user, const QString& password  )
 {
-    d->m_proxyHost = proxyHost;
-    d->m_proxyPort = proxyPort;
-    d->m_user = user;
-    d->m_password = password;
-
     QNetworkProxy::ProxyType type = QNetworkProxy::HttpProxy;
 
     // Make sure that no proxy is used for an empty string or the default value: 
     if ( proxyHost.isEmpty() || proxyHost == "http://" )
         type = QNetworkProxy::NoProxy;
 
-    QNetworkProxy proxy( type, d->m_proxyHost, d->m_proxyPort, d->m_user, d->m_password );
+    QString hostName = proxyHost;
+    if ( hostName.startsWith("http://" ) ) {
+        hostName = hostName.mid( QString( "http://" ).size() );
+    }
+    
+    QNetworkProxy proxy( type, hostName, proxyPort, user, password );
     QNetworkProxy::setApplicationProxy( proxy );
-    qDebug() << "MarbleWidget::setProxy" << type << d->m_proxyHost << d->m_proxyPort << d->m_user << d->m_password;
 }
 
 QString MarbleWidget::proxyHost() const
 {
-    return d->m_proxyHost;
+    return QNetworkProxy::applicationProxy().hostName();
 }
 
 quint16 MarbleWidget::proxyPort() const
 {
-    return d->m_proxyPort;
+    return QNetworkProxy::applicationProxy().port();
 }
 
 QString MarbleWidget::user() const
 {
-    return d->m_user;
+    return QNetworkProxy::applicationProxy().user();
 }
 
 QString MarbleWidget::password() const
 {
-    return d->m_password;
+    return QNetworkProxy::applicationProxy().password();
 }
 
 QList<RenderPlugin *> MarbleWidget::renderPlugins() const
@@ -1285,11 +1381,55 @@ QList<RenderPlugin *> MarbleWidget::renderPlugins() const
     return d->m_model->renderPlugins();
 }
 
+void MarbleWidget::readPluginSettings( QSettings& settings )
+{
+    foreach( RenderPlugin *plugin, renderPlugins() ) {
+        settings.beginGroup( QString( "plugin_" ) + plugin->nameId() );
+
+        QHash<QString,QVariant> hash = plugin->settings();
+
+        foreach ( const QString& key, settings.childKeys() ) {
+            hash.insert( key, settings.value( key ) );
+        }
+
+        plugin->setSettings( hash );
+
+        settings.endGroup();
+    }
+}
+
+void MarbleWidget::writePluginSettings( QSettings& settings ) const
+{
+    foreach( RenderPlugin *plugin, renderPlugins() ) {
+        settings.beginGroup( QString( "plugin_" ) + plugin->nameId() );
+
+        QHash<QString,QVariant> hash = plugin->settings();
+
+        QHash<QString,QVariant>::iterator it = hash.begin();
+        while( it != hash.end() ) {
+            settings.setValue( it.key(), it.value() );
+            ++it;
+        }
+
+        settings.endGroup();
+    }
+}
+
 QList<AbstractFloatItem *> MarbleWidget::floatItems() const
 {
     return d->m_model->floatItems();
 }
 
+void MarbleWidget::changeEvent ( QEvent * event )
+{
+    if (event->type() == QEvent::EnabledChange)
+    {
+        setInputEnabled(isEnabled());
+    }
+
+    QWidget::changeEvent(event);
+}
+
 }
 
 #include "MarbleWidget.moc"
