@@ -5,8 +5,8 @@
 // find a copy of this license in LICENSE.txt in the top directory of
 // the source code.
 //
-// Copyright 2006-2007 Torsten Rahn <tackat@kde.org>"
-// Copyright 2007      Inge Wallin  <ingwa@kde.org>"
+// Copyright 2006-2007 Torsten Rahn <tackat@kde.org>
+// Copyright 2007      Inge Wallin  <ingwa@kde.org>
 //
 
 #include "VectorComposer.h"
@@ -14,9 +14,8 @@
 #include <cmath>
 
 #include <QtGui/QColor>
-#include <QtCore/QDebug>
-#include <QtCore/QTimer>
 
+#include "MarbleDebug.h"
 #include "GeoPolygon.h"
 #include "GeoPainter.h"
 #include "global.h"
@@ -27,8 +26,9 @@
 
 using namespace Marble;
 
-VectorComposer::VectorComposer()
-    : m_vectorMap( new VectorMap() ),
+VectorComposer::VectorComposer( QObject * parent )
+    : QObject( parent ),
+      m_vectorMap( new VectorMap() ),
       m_coastLines( new PntMap() ),
       m_islands( new PntMap() ),
       m_lakeislands( new PntMap() ),
@@ -46,15 +46,24 @@ VectorComposer::VectorComposer()
       m_textureLandBrush( QBrush( QColor( 255, 0, 0 ) ) ),
       m_textureGlacierBrush( QBrush( QColor( 0, 255, 0 ) ) ),
       m_textureLakeBrush( QBrush( QColor( 0, 0, 0 ) ) ),
-      m_dateLineBrush( QBrush( Qt::NoBrush ) )
+      m_dateLineBrush( QBrush( Qt::NoBrush ) ),
+      m_coastLinesLoaded( false ),
+      m_overlaysLoaded( false )
 {
     m_textureBorderPen.setStyle( Qt::SolidLine );
     m_textureBorderPen.setColor( QColor( 0, 255, 0 ) );
     m_dateLinePen.setStyle( Qt::DashLine );
     m_dateLinePen.setColor( QColor( 0, 0, 0 ) );
 
-    loadCoastlines();
-    loadOverlay();
+    connect( m_coastLines, SIGNAL( initialized() ), SIGNAL( datasetLoaded() ) );
+    connect( m_islands, SIGNAL( initialized() ), SIGNAL( datasetLoaded() ) );
+    connect( m_lakeislands, SIGNAL( initialized() ), SIGNAL( datasetLoaded() ) );
+    connect( m_lakes, SIGNAL( initialized() ), SIGNAL( datasetLoaded() ) );
+    connect( m_glaciers, SIGNAL( initialized() ), SIGNAL( datasetLoaded() ) );
+    connect( m_rivers, SIGNAL( initialized() ), SIGNAL( datasetLoaded() ) );
+    connect( m_countries, SIGNAL( initialized() ), SIGNAL( datasetLoaded() ) );
+    connect( m_usaStates, SIGNAL( initialized() ), SIGNAL( datasetLoaded() ) );
+    connect( m_dateLine, SIGNAL( initialized() ), SIGNAL( datasetLoaded() ) );
 }
 
 VectorComposer::~VectorComposer()
@@ -73,17 +82,22 @@ VectorComposer::~VectorComposer()
 
 void VectorComposer::loadCoastlines()
 {
+    mDebug() << Q_FUNC_INFO;
+
+    // Coastlines
     m_coastLines->load( MarbleDirs::path( "mwdbii/PCOAST.PNT" ) );
     m_islands->load( MarbleDirs::path( "mwdbii/PISLAND.PNT" ) );
     m_lakeislands->load( MarbleDirs::path( "mwdbii/PLAKEISLAND.PNT" ) );
     m_lakes->load( MarbleDirs::path( "mwdbii/PLAKE.PNT" ) );
-}
 
-void VectorComposer::loadOverlay()
-{
     // Ice and snow ...
     m_glaciers->load( MarbleDirs::path( "mwdbii/PGLACIER.PNT" ) );
+}
 
+void VectorComposer::loadOverlays()
+{
+    mDebug() << Q_FUNC_INFO;
+    
     // The rivers.
     m_rivers->load( MarbleDirs::path( "mwdbii/RIVER.PNT" ) );
 
@@ -99,6 +113,11 @@ void VectorComposer::loadOverlay()
 
 void VectorComposer::drawTextureMap(ViewParams *viewParams)
 {
+    if ( !m_coastLinesLoaded ) {
+        m_coastLinesLoaded = true;
+        loadCoastlines();
+    }
+    
     QPaintDevice  *origimg = viewParams->coastImage();
     Quaternion     rotAxis = viewParams->planetAxis();
 
@@ -106,8 +125,8 @@ void VectorComposer::drawTextureMap(ViewParams *viewParams)
 
     bool antialiased = false;
 
-    if (   viewParams->mapQuality() == Marble::High
-        || viewParams->mapQuality() == Marble::Print )
+    if (   viewParams->mapQuality() == Marble::HighQuality
+        || viewParams->mapQuality() == Marble::PrintQuality )
     {
         antialiased = true;
     }
@@ -170,18 +189,23 @@ void VectorComposer::drawTextureMap(ViewParams *viewParams)
                                viewParams->mapQuality() );
     }
 
-    // qDebug() << "TextureMap calculated nodes: " << m_vectorMap->nodeCount();
+    // mDebug() << "TextureMap calculated nodes: " << m_vectorMap->nodeCount();
 }
 
 void VectorComposer::paintBaseVectorMap( GeoPainter *painter, 
                                          ViewParams *viewParams )
 {
+    if ( !m_coastLinesLoaded ) {
+        m_coastLinesLoaded = true;
+        loadCoastlines();
+    }
+
     Quaternion  rotAxis = viewParams->planetAxis();
 
     bool antialiased = false;
 
-    if (   viewParams->mapQuality() == Marble::High
-        || viewParams->mapQuality() == Marble::Print )
+    if (   viewParams->mapQuality() == Marble::HighQuality
+        || viewParams->mapQuality() == Marble::PrintQuality )
     {
 	antialiased = true;
     }
@@ -258,8 +282,8 @@ void VectorComposer::paintVectorMap( GeoPainter *painter,
 
     bool antialiased = false;
 
-    if (   viewParams->mapQuality() == Marble::High
-        || viewParams->mapQuality() == Marble::Print )
+    if (   viewParams->mapQuality() == Marble::HighQuality
+        || viewParams->mapQuality() == Marble::PrintQuality )
     {
         antialiased = true;
     }
@@ -269,7 +293,13 @@ void VectorComposer::paintVectorMap( GeoPainter *painter,
     viewParams->propertyValue( "coastlines", showCoastlines );
 
     if ( showCoastlines ) {
-        m_vectorMap->setzBoundingBoxLimit( 0.4 ); 
+
+        if ( !m_coastLinesLoaded ) {
+            m_coastLinesLoaded = true;
+            loadCoastlines();
+        }
+
+        m_vectorMap->setzBoundingBoxLimit( 0.4 );
         m_vectorMap->setzPointLimit( 0 ); // 0.6 results in green pacific
     
         m_vectorMap->createFromPntMap( m_coastLines, viewParams->viewport() );
@@ -303,6 +333,10 @@ void VectorComposer::paintVectorMap( GeoPainter *painter,
     viewParams->propertyValue( "rivers", showRivers );
 
     if ( showWaterbodies && showRivers ) {
+        if ( !m_overlaysLoaded ) {
+            m_overlaysLoaded = true;
+            loadOverlays();
+        }
         // Rivers
          m_vectorMap->setzBoundingBoxLimit( -1.0 );
          m_vectorMap->setzPointLimit( -1.0 );
@@ -317,6 +351,10 @@ void VectorComposer::paintVectorMap( GeoPainter *painter,
     viewParams->propertyValue( "borders", showBorders );
 
     if ( showBorders ) {
+        if ( !m_overlaysLoaded ) {
+            m_overlaysLoaded = true;
+            loadOverlays();
+        }
         // Countries
          m_vectorMap->setzBoundingBoxLimit( -1.0 );
          m_vectorMap->setzPointLimit( -1.0 );
@@ -339,8 +377,8 @@ void VectorComposer::paintVectorMap( GeoPainter *painter,
         QPen borderDashPen( Qt::black );
         m_vectorMap->setBrush( m_countryBrush );
 
-        if ( viewParams->mapQuality() == Marble::High 
-          || viewParams->mapQuality() == Marble::Print ) {
+        if ( viewParams->mapQuality() == Marble::HighQuality 
+          || viewParams->mapQuality() == Marble::PrintQuality ) {
 
             countryPen.setColor( penColor );
             m_vectorMap->setPen( countryPen );
@@ -356,9 +394,10 @@ void VectorComposer::paintVectorMap( GeoPainter *painter,
                 m_vectorMap->paintMap( painter, antialiased );
             }
         }
-        if ( viewParams->mapQuality() == Marble::Outline
-          || viewParams->mapQuality() == Marble::Low 
-          || viewParams->mapQuality() == Marble::Normal ) {
+        if ( viewParams->mapQuality() == Marble::OutlineQuality
+          || viewParams->mapQuality() == Marble::LowQuality
+          || viewParams->mapQuality() == Marble::NormalQuality ) {
+
             if ( !showCoastlines ) {
                 countryPen.setWidthF( 1.0 );
                 countryPen.setColor( penColor.darker(115) );
@@ -373,22 +412,22 @@ void VectorComposer::paintVectorMap( GeoPainter *painter,
         m_vectorMap->createFromPntMap( m_usaStates, viewParams->viewport() );
 
         QPen statePen( m_statePen);
-        if ( viewParams->mapQuality() == Marble::Outline
-          || viewParams->mapQuality() == Marble::Low ) {
+        if ( viewParams->mapQuality() == Marble::OutlineQuality
+          || viewParams->mapQuality() == Marble::LowQuality ) {
             statePen.setStyle( Qt::SolidLine );
         }
         m_vectorMap->setPen( statePen );
         m_vectorMap->setBrush( m_stateBrush );
         m_vectorMap->paintMap( painter, antialiased );
-        
+
         // International Dateline
         m_vectorMap->setzBoundingBoxLimit( -1.0 );
         m_vectorMap->setzPointLimit( -1.0 );
         m_vectorMap->createFromPntMap( m_dateLine, viewParams->viewport() );
 
         QPen dateLinePen( m_dateLinePen);
-        if ( viewParams->mapQuality() == Marble::Outline
-          || viewParams->mapQuality() == Marble::Low ) {
+        if ( viewParams->mapQuality() == Marble::OutlineQuality
+          || viewParams->mapQuality() == Marble::LowQuality ) {
             dateLinePen.setStyle( Qt::SolidLine );
         }
         m_vectorMap->setPen( dateLinePen );
@@ -396,7 +435,7 @@ void VectorComposer::paintVectorMap( GeoPainter *painter,
         m_vectorMap->paintMap( painter, antialiased );
     }
 
-    // qDebug() << "M_VectorMap calculated nodes: " << m_vectorMap->nodeCount();
+    // mDebug() << "M_VectorMap calculated nodes: " << m_vectorMap->nodeCount();
 }
 
 
@@ -404,3 +443,5 @@ void VectorComposer::resizeMap( int width, int height )
 {
     m_vectorMap->resizeMap( width, height );
 }
+
+#include "VectorComposer.moc"
