@@ -24,12 +24,18 @@
 
 #include "GeoTagHandler.h"
 
-class DgmlHeadTagHandler : public GeoTagHandler {
- public:
-    DgmlHeadTagHandler();
-    virtual ~DgmlHeadTagHandler();
+namespace Marble
+{
+namespace dgml
+{
 
+class DgmlHeadTagHandler : public GeoTagHandler
+{
+ public:
     virtual GeoNode* parse(GeoParser&) const;
 };
 
+}
+}
+
 #endif // DgmlHeadTagHandler_h
