@@ -24,12 +24,18 @@
 
 #include "GeoTagHandler.h"
 
-class DgmlSourceFileTagHandler : public GeoTagHandler {
-public:
-    DgmlSourceFileTagHandler();
-    virtual ~DgmlSourceFileTagHandler();
+namespace Marble
+{
+namespace dgml
+{
 
+class DgmlSourceFileTagHandler : public GeoTagHandler
+{
+public:
     virtual GeoNode* parse(GeoParser&) const;
 };
 
+}
+}
+
 #endif // DgmlSourceFileTagHandler_h
