@@ -24,12 +24,18 @@
 
 #include "GeoTagHandler.h"
 
-class DgmlValueTagHandler : public GeoTagHandler {
- public:
-    DgmlValueTagHandler();
-    virtual ~DgmlValueTagHandler();
+namespace Marble
+{
+namespace dgml
+{
 
+class DgmlValueTagHandler : public GeoTagHandler
+{
+ public:
     virtual GeoNode* parse(GeoParser&) const;
 };
 
+}
+}
+
 #endif // DgmlValueTagHandler_h
