@@ -24,12 +24,18 @@
 
 #include "GeoTagHandler.h"
 
-class GPXgpxTagHandler : public GeoTagHandler {
-public:
-    GPXgpxTagHandler();
-    virtual ~GPXgpxTagHandler();
+namespace Marble
+{
+namespace gpx
+{
 
+class GPXgpxTagHandler : public GeoTagHandler
+{
+public:
     virtual GeoNode* parse(GeoParser&) const;
 };
 
+}
+}
+
 #endif // GPXgpxTagHandler_h
