@@ -24,12 +24,18 @@
 
 #include "GeoTagHandler.h"
 
-class KmlStyleTagHandler : public GeoTagHandler {
-public:
-    KmlStyleTagHandler();
-    virtual ~KmlStyleTagHandler();
+namespace Marble
+{
+namespace kml
+{
 
+class KmlStyleTagHandler : public GeoTagHandler
+{
+public:
     virtual GeoNode* parse(GeoParser&) const;
 };
 
+}
+}
+
 #endif // KmlStyleTagHandler_h
