@@ -57,6 +57,7 @@ class MarblePart: public KParts::ReadOnlyPart
     void  showDistance( const QString& position);
     void  showZoomLevel( int zoomLevel );
     void  mapThemeChanged( const QString& newMapTheme );
+    void  createPluginMenus();
 
   private Q_SLOTS:
     void  initObject();
@@ -115,10 +116,31 @@ class MarblePart: public KParts::ReadOnlyPart
     void  editSettings();
 
     void  slotEnableButtonApply();
-    void  slotApply();
-    void  slotCancel();
+    void  applyPluginState();
+    void  retrievePluginState();
 
     void  slotUpdateSettings();
+    void reload();
+
+    /**
+     * Shows the about dialog for the plugin with the corresponding @p nameId.
+     */
+    void  showPluginAboutDialog( QString nameId );
+
+    /**
+     * Shows the configuration dialog for the plugin with the corresponding @p nameId.
+     */
+    void  showPluginConfigDialog( QString nameId );
+
+    /**
+     * Saves the settings of all plugins.
+     */
+    void writePluginSettings();
+
+    /**
+     * Reads the settings of all plugins.
+     */
+    void readPluginSettings();
 
   private:
     void  setupActions();
@@ -181,7 +203,7 @@ class MarblePart: public KParts::ReadOnlyPart
     void updateStatusBar();
 
     KParts::StatusBarExtension *m_statusBarExtension;
-    
+
     // Information about the graphics system
     Marble::GraphicsSystem m_initialGraphicsSystem;
     Marble::GraphicsSystem m_previousGraphicsSystem;
