@@ -29,10 +29,9 @@
 #include "editor/editor.h"
 #include "statistics-dialogs/StatisticsDialog.h"
 #include "settings/parleyprefs.h"
-#include "settings/documentproperties.h"
 #include "configure-practice/configurepracticedialog.h"
-#include "practiceold/testentrymanager.h"
-//#include "practice/parleypracticemainwindow.h"
+#include "practiceold/vocabularypractice.h"
+
 #include "prefs.h"
 #include "welcomescreen/welcomescreen.h"
 
@@ -40,27 +39,35 @@
 #include <KRecentFilesAction>
 #include <KMessageBox>
 #include <KTipDialog>
-#include <knewstuff2/ui/knewstuffaction.h>
+#include <knewstuff3/knewstuffaction.h>
 #include <KXMLGUIFactory>
 #include <KToolBar>
 
 #include <QtCore/QTimer>
 
-ParleyMainWindow::ParleyMainWindow(const QString& appName, const KUrl & filename) : KXmlGuiWindow(0), m_currentComponent(NoComponent) //, m_practice(0)
+ParleyMainWindow* ParleyMainWindow::s_instance = 0;
+ParleyMainWindow* ParleyMainWindow::instance()
 {
-    m_appName = appName;
-    m_document = new ParleyDocument(this);
+    return s_instance;
+}
+
+ParleyMainWindow::ParleyMainWindow(const KUrl& filename)
+    :KXmlGuiWindow(0)
+    ,m_currentComponent(NoComponent)
+{
+    s_instance = this;
+    m_document = ParleyDocument::instance();
 
     setCentralWidget(new QWidget());
     centralWidget()->setLayout(new QHBoxLayout());
 
     initWelcomeScreen();
 
-    initActions();
-
     m_editor = new Editor(this);
     m_editor->hide();
 
+    initActions();
+
     bool showWelcomeScreen = false;
 
     setupGUI(ToolBar | Keys | StatusBar | Create);
@@ -90,12 +97,23 @@ ParleyMainWindow::ParleyMainWindow(const QString& appName, const KUrl & filename
     QTimer::singleShot( 0, this, SLOT( startupTipOfDay() ) );
 }
 
+ParleyMainWindow::~ParleyMainWindow()
+{
+    m_editor->saveState();
+    ParleyDocument::destroy();
+}
+
 void ParleyMainWindow::addRecentFile(const KUrl &url, const QString &name)
 {
     m_recentFilesAction->addUrl(url, name);
     m_recentFilesAction->saveEntries(KGlobal::config()->group("Recent Files"));
 }
 
+void ParleyMainWindow::updateRecentFilesModel()
+{
+    m_welcomeScreen->updateRecentFilesModel();
+}
+
 void ParleyMainWindow::saveOptions()
 {
 ///@todo save selection per document
@@ -157,22 +175,6 @@ void ParleyMainWindow::slotCloseDocument()
     showWelcomeScreen();
 }
 
-void ParleyMainWindow::slotDocumentProperties()
-{
-    DocumentProperties* titleAuthorWidget = new DocumentProperties(m_document->document(), false, this);
-    KDialog* titleAuthorDialog;
-    titleAuthorDialog = new KDialog(this);
-    titleAuthorDialog->setMainWidget( titleAuthorWidget );
-
-    // the language options are only shown, when this is used to create a new document.
-    titleAuthorWidget->languageGroupBox->setVisible(false);
-    titleAuthorDialog->setCaption(i18nc("@title:window document properties", "Properties for %1", m_document->document()->url().url()));
-    connect(titleAuthorDialog, SIGNAL(accepted()), titleAuthorWidget, SLOT(accept()));
-    titleAuthorDialog->exec();
-    slotUpdateWindowCaption();
-    delete titleAuthorDialog;
-}
-
 void ParleyMainWindow::configurePractice()
 {
     ConfigurePracticeDialog configurePracticeDialog(m_document->document(), this, "practice settings",  Prefs::self());
@@ -211,8 +213,8 @@ void ParleyMainWindow::startPractice()
 //        }
 //    } else {
         hide();
-        TestEntryManager testManager(m_document->document(), this);
-        testManager.startPractice();
+        VocabularyPractice practice(m_document->document(), this);
+        practice.startPractice();
         show();
 //    }
 }
@@ -279,7 +281,7 @@ void ParleyMainWindow::initActions()
     fileOpen->setToolTip(fileOpen->whatsThis());
     fileOpen->setStatusTip(fileOpen->whatsThis());
 
-    KAction* fileGHNS = KNS::standardAction(i18n("Download New Vocabularies..."), m_document, SLOT(slotGHNS()), actionCollection(), "file_ghns");
+    KAction* fileGHNS = KNS3::standardAction(i18n("Download New Vocabularies..."), m_document, SLOT(slotGHNS()), actionCollection(), "file_ghns");
     fileGHNS->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_G));
     fileGHNS->setWhatsThis(i18n("Downloads new vocabulary collections"));
     fileGHNS->setToolTip(fileGHNS->whatsThis());
@@ -340,7 +342,7 @@ void ParleyMainWindow::initActions()
     KAction* fileProperties = new KAction(this);
     actionCollection()->addAction("file_properties", fileProperties);
     fileProperties->setText(i18n("&Properties..."));
-    connect(fileProperties, SIGNAL(triggered(bool)), SLOT(slotDocumentProperties()));
+    connect(fileProperties, SIGNAL(triggered(bool)), m_editor, SLOT(slotDocumentProperties()));
     fileProperties->setIcon(KIcon("document-properties"));
     fileProperties->setWhatsThis(i18n("Edit document properties"));
     fileProperties->setToolTip(fileProperties->whatsThis());
@@ -460,10 +462,6 @@ void ParleyMainWindow::switchComponent(Component component)
 
     m_currentComponent = component;
     setupToolbarMenuActions();
-
-    if (component == EditorComponent) {
-        m_editor->updateScriptMenu();
-    }
 }
 
 void ParleyMainWindow::showDocumentActions(bool open, bool edit)
