@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    Copyright 2008 Frederik Gladhorn <frederik.gladhorn@kdemail.net>
+    Copyright 2008-2009 Frederik Gladhorn <gladhorn@kde.org>
 
  ***************************************************************************/
 
@@ -18,6 +18,7 @@
 
 #include "containermodel.h"
 
+
 /**
   * Model for the tree of lessons.
   */
@@ -34,7 +35,11 @@ public:
 
 
     explicit LessonModel(QObject *parent = 0);
-
+    
+    virtual Qt::ItemFlags flags(const QModelIndex &index) const;
+    virtual QVariant data(const QModelIndex &index, int role) const;
+    virtual bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole);
+    
     /**
      * Divide a lesson into smaller ones.
      * Tip: If you create a lesson that is >= the original one and use random order, you get your lesson reshuffled. Maybe that is sometimes useful. For now the lessons are appended at the end.
